/*
 * An opener for a test file containing generated content.
 *
 * Copyright (C) 2021, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <fsserver/opener_resource.h>



/* Support for providing access to files. */

class TestFileOpener : public OpenerResource
{
protected:
    offset_t _file_size;

    /* Convenience methods determining different object types. */

    virtual bool accessing_directory(flags_t flags, fileid_t fileid);

    virtual bool accessing_file(flags_t flags, fileid_t fileid);

public:
    explicit TestFileOpener(ResourceRegistry *registry, offset_t file_size=0);

    virtual ~TestFileOpener();

    /* Configurable methods. */

    virtual long get_fileid(const char *path, flags_t flags, fileid_t *fileid);

    virtual long make_accessor(flags_t flags, fileid_t fileid,
                               Accessor **accessor);

    virtual long make_directory_accessor(flags_t flags, fileid_t fileid,
                                         DirectoryAccessor **accessor);

    virtual long remove_object(fileid_t fileid);

    virtual long rename_object(const char *source, const char *target);

    virtual long unlink_object(fileid_t parent_fileid, fileid_t fileid);
};

// vim: tabstop=4 expandtab shiftwidth=4
